links_dict = {
    "3MINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/3mindia/MI42",
        "investing_link": "https://in.investing.com/equities/3m-india",
    },
    "AARTIDRUGS": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/chemicals/aartiindustries/AI45",
        "investing_link": "https://in.investing.com/equities/aarti-drugs-ltd",
    },
    "AAVAS": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/finance-general/aavasfinanciers/AF17",
        "investing_link": "https://in.investing.com/equities/aavas-financiers",
    },
    "ABB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/infrastructure-general/abbindia/ABB",
        "investing_link": "https://in.investing.com/equities/abb-limited",
    },
    "ABBOTINDIA": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/abbottindia/AI51",
        "investing_link": "https://in.investing.com/equities/abbott-india-ltd",
    },
    "ACC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/acc/ACC06",
        "investing_link": "https://in.investing.com/equities/acc",
    },
    "ADANIENT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/trading/adanienterprises/AE13",
        "investing_link": "https://in.investing.com/equities/adani-enterprises",
    },
    "ADANIGREEN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/adanigreenenergylimited/ADANI54145",
        "investing_link": "https://in.investing.com/equities/adani-green-energy",
    },
    "ADANIPORTS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/infrastructure-general/adaniportsspecialeconomiczone/MPS",
        "investing_link": "https://in.investing.com/equities/mundra-port-special-eco.-zone",
    },
    "ATGL": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/adanitotalgas/adanitotalgas/ADG01",
        "investing_link": "https://in.investing.com/equities/adani-gas",
    },
    "ADANITRANS": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/power-transmissionequipment/adanitransmission/AT22",
        "investing_link": "https://in.investing.com/equities/adani-transmission-ltd",
    },
    "ABCAPITAL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/adityabirlacapital/ABC9",
        "investing_link": "https://in.investing.com/equities/aditya-birla",
    },
    "ABFRL": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/retail/adityabirlafashionretail/PFR",
        "investing_link": "https://in.investing.com/equities/pantaloons-fashion-retail",
    },
    "ABSLAMC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investment/adityabirlasunlifeamc/ABS",
        "investing_link": "https://in.investing.com/equities/aditya-birla-sun-life-amc",
    },
    "ADVENZYMES": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/advancedenzymetechnologies/AET",
        "investing_link": "https://in.investing.com/equities/advanced-enzyme-technologies-ltd",
    },
    "AEGISCHEM": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/transportlogistics/aegislogistics/AL9",
        "investing_link": "https://in.investing.com/equities/aegis-logistics-ltd",
    },
    "AFFLE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/it-servicesconsulting/affleindia/AI82",
        "investing_link": "https://in.investing.com/equities/affle-india-ltd",
    },
    "AIAENG": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/castingsforgings/aiaengineering/AIE01",
        "investing_link": "https://in.investing.com/equities/aia-engineering",
    },
    "AJANTPHARM": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/ajantapharma/AP22",
        "investing_link": "https://in.investing.com/equities/ajanta-pharma-ltd",
    },
    "APLLTD": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/alembicpharmaceuticals/AP35",
        "investing_link": "https://in.investing.com/equities/alembic-pharmaceuticals-ltd",
    },
    "ALKEM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/alkemlaboratories/AL05",
        "investing_link": "https://in.investing.com/equities/alkem-laboratories-ltd",
    },
    "ALKYLAMINE": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/chemicals/alkylamineschemicals/AAC",
        "investing_link": "https://in.investing.com/equities/alkyl-amines-chemicals-ltd",
    },
    "ALLCARGO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/transportlogistics/allcargologistics/AGL02",
        "investing_link": "https://in.investing.com/equities/allcargo-logistics",
    },
    "ALOKINDS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-weaving/alokindustries/AI54",
        "investing_link": "https://in.investing.com/equities/alok-industries",
    },
    "AMARAJABAT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries/amararajabatteries/ARB",
        "investing_link": "https://in.investing.com/equities/amara-raja-batteries",
    },
    "AMBER": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/amberenterprisesindialimited/AEI01",
        "investing_link": "https://in.investing.com/equities/amber-enterprises-india",
    },
    "AMBUJACEM": {
        "moneycontrol_link": "http://www.moneycontrol.com/india/stockpricequote/cement-major/ambujacements/AC18",
        "investing_link": "https://in.investing.com/equities/ambuja-cements",
    },
    "ANGELONE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-stock-broking/angelone/ABL03",
        "investing_link": "https://in.investing.com/equities/angel-broking-ltd",
    },
    "ANURAS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/speciality-chemicals/anupamrasayanindia/ARI02",
        "investing_link": "https://in.investing.com/equities/anupam-rasayan-india-nse",
    },
    "APLAPOLLO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/steel-tubespipes/aplapollotubes/BT09",
        "investing_link": "https://in.investing.com/equities/apl-apollo-tubes-ltd",
    },
    "APOLLOHOSP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hospitalsmedical-services/apollohospitalsenterprises/AHE",
        "investing_link": "https://in.investing.com/equities/apollo-hospitals",
    },
    "APOLLOTYRE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/tyres/apollotyres/AT14",
        "investing_link": "https://in.investing.com/equities/apollo-tyres",
    },
    "APTUS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-housing/aptusvaluehousingfinanceindia/AVH",
        "investing_link": "https://in.investing.com/equities/aptus-value-housing-finance-india",
    },
    "ASAHIINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/glassglass-products/asahiindiaglass/AIG01",
        "investing_link": "https://in.investing.com/equities/asahi-india-glass",
    },
    "ASHOKLEY": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-lcvshcvs/ashokleyland/AL",
        "investing_link": "https://in.investing.com/equities/ashok-leyland",
    },
    "ASIANPAINT\r": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/paintsvarnishes/asianpaints/AP31",
        "investing_link": "https://in.investing.com/equities/asian-paints",
    },
    "ASTERDM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/asterdmhealthcareltd/ADH",
        "investing_link": "https://in.investing.com/equities/aster-dm-healthcare-ltd",
    },
    "ASTRAL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/plastics/astrallimited/APT02",
        "investing_link": "https://in.investing.com/equities/astral-poly-technik-ltd",
    },
    "ASTRAZEN\r": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/astrazenecapharma/AZP",
        "investing_link": "https://in.investing.com/equities/astrazeneca-pharma-india",
    },
    "ATUL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/atul/A06",
        "investing_link": "https://in.investing.com/equities/atul",
    },
    "AUBANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/ausmallfinancebank/ASF02",
        "investing_link": "https://in.investing.com/equities/au-small-finance-bank-ltd",
    },
    "AUROPHARMA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/aurobindopharma/AP",
        "investing_link": "https://in.investing.com/equities/aurobindo-pharma",
    },
    "AVANTIFEED": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/aquaculture/avantifeeds/AF21",
        "investing_link": "https://in.investing.com/equities/avanti-feeds-ltd",
    },
    "DMART": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/retail/avenuesupermarts/AS19",
        "investing_link": "https://in.investing.com/equities/avenue-supermarts-ltd",
    },
    "AXISBANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/axisbank/AB16",
        "investing_link": "https://in.investing.com/equities/axis-bank",
    },
    "BAJAJ-AUTO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-23-wheelers/bajajauto/BA10",
        "investing_link": "https://in.investing.com/equities/bajaj-auto",
    },
    "BAJAJELEC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/domestic-appliances/bajajelectricals/BE",
        "investing_link": "https://in.investing.com/equities/bajaj-electricals",
    },
    "BAJFINANCE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-nbfc/bajajfinance/BAF",
        "investing_link": "https://in.investing.com/equities/bajaj-finance",
    },
    "BAJAJFINSV": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/bajajfinserv/BF04",
        "investing_link": "https://in.investing.com/equities/bajaj-finserv-limited",
    },
    "BAJAJHLDNG": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/bajajholdingsinvestment/BHI",
        "investing_link": "https://in.investing.com/equities/bajaj-holdings---investment",
    },
    "BALAMINES": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/balajiamines/BA05",
        "investing_link": "https://in.investing.com/equities/balaji-amines-ltd",
    },
    "BALKRISIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/tyres/balkrishnaindustries/BI03",
        "investing_link": "https://in.investing.com/equities/balkrishna-industries-ltd",
    },
    "BALRAMCHIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/sugar/balrampurchinimills/BCM",
        "investing_link": "https://in.investing.com/equities/balrampur-chini-mills",
    },
    "BANDHANBNK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/bandhanbank/BB09",
        "investing_link": "https://in.investing.com/equities/bandhan-bank-ltd",
    },
    "BANKBARODA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/bankbaroda/BOB",
        "investing_link": "https://in.investing.com/equities/bank-of-baroda",
    },
    "BANKINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/bankindia/BOI",
        "investing_link": "https://in.investing.com/equities/bank-of-baroda",
    },
    "MAHABANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/bankmaharashtra/BM05",
        "investing_link": "https://in.investing.com/equities/bank-of-maharashtra",
    },
    "BASF": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/basfindia/BAS",
        "investing_link": "https://in.investing.com/equities/basf-india",
    },
    "BATAINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/leather-products/bataindia/BI01",
        "investing_link": "https://in.investing.com/equities/bata-india",
    },
    "BAYERCROP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pesticidesagro-chemicals/bayercropscience/BC12",
        "investing_link": "https://in.investing.com/equities/bayer-cropscience-ltd",
    },
    "BERGEPAINT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/paintsvarnishes/bergerpaintsindia/BPI02",
        "investing_link": "https://in.investing.com/equities/berger-paints-(i)",
    },
    "BDL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/bharatdynamicsltd/BDL01",
        "investing_link": "https://in.investing.com/equities/bharat-dynamics-ltd",
    },
    "BEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/electricals/bharatelectronics/BE03",
        "investing_link": "https://in.investing.com/equities/bharat-electronics",
    },
    "BHARATFORG": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/castingsforgings/bharatforge/BF03",
        "investing_link": "https://in.investing.com/equities/bharat-forge",
    },
    "BHEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/castingsforgings/bharatforge/BF03",
        "investing_link": "https://in.investing.com/equities/bharat-heavy-electricals",
    },
    "BPCL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/refineries/bharatpetroleumcorporation/BPC",
        "investing_link": "https://in.investing.com/equities/bharat-petroleum",
    },
    "BHARTIARTL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/telecommunications-service/bhartiairtel/BA08",
        "investing_link": "https://in.investing.com/equities/bharti-airtel",
    },
    "BIOCON": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/biocon/BL03",
        "investing_link": "https://in.investing.com/equities/biocon",
    },
    "BIRLACORPN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/birlacorporation/BC07",
        "investing_link": "https://in.investing.com/equities/birla-corporation",
    },
    "BSOFT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software-mediumsmall/birlasoft/KPI02",
        "investing_link": "https://in.investing.com/equities/kpit-cummins-infosystems",
    },
    "BLUEDART": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/couriers/bluedartexpress/BDE",
        "investing_link": "https://in.investing.com/equities/blue-dart-express",
    },
    "BLUESTARCO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/consumer-goods-white-goods/bluestar/BS",
        "investing_link": "https://in.investing.com/equities/blue-star-infotech",
    },
    "BBTC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/plantations-teacoffee/bombayburmahtradingcorporation/BBT",
        "investing_link": "https://in.investing.com/equities/bomburmah",
    },
    "BORORENEW": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/glassglass-products/borosilrenewablesltd/BGW",
        "investing_link": "https://in.investing.com/equities/borosil-renewables-ltd",
    },
    "BOSCHLTD": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries/bosch/B05",
        "investing_link": "https://in.investing.com/equities/bosch",
    },
    "BRIGADE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/brigadeenterprises/BE08",
        "investing_link": "https://in.investing.com/equities/brigade-enterprises",
    },
    "BCG": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software-mediumsmall/brightcomgroup/LGS",
        "investing_link": "https://in.investing.com/equities/lycos-internet-ltd",
    },
    "BRITANNIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/food-processing/britanniaindustries/BI",
        "investing_link": "https://in.investing.com/equities/britannia-industries",
    },
    "BSE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/bselimited/B08",
        "investing_link": "https://in.investing.com/equities/bse-ltd",
    },
    "MAPMYINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/software/ceinfosystemsmapmyindia/CIS02",
        "investing_link": "https://in.investing.com/equities/ce-info-systems",
    },
    "CANFINHOME": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-housing/canfinhomes/CFH",
        "investing_link": "https://in.investing.com/equities/can-fin-homes",
    },
    "CANBK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/canarabank/CB06",
        "investing_link": "https://in.investing.com/equities/canara-bank",
    },
    "CAPLIPOINT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/caplinpointlaboratories/CPL",
        "investing_link": "https://in.investing.com/equities/caplin-point-laboratories-ltd",
    },
    "CGCL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-general/capriglobalcapital/MMF05",
        "investing_link": "https://in.investing.com/equities/capri-global-capital-ltd",
    },
    "CARBORUNIV": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/abrasives/carborundumuniversal/CU",
        "investing_link": "https://in.investing.com/equities/carborundum-universal",
    },
    "CASTROLIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/lubricants/castrolindia/CI01",
        "investing_link": "https://in.investing.com/equities/castrol-india",
    },
    "CCL\r": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/plantations-teacoffee/cclproductsindia/CC10",
        "investing_link": "https://in.investing.com/equities/ccl-products-india-ltd",
    },
    "CEATLTD": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/tyres/ceat/C07",
        "investing_link": "https://in.investing.com/equities/ceat-ltd",
    },
    "CENTRALBK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/centralbankindia/CBO01",
        "investing_link": "https://in.investing.com/equities/central-bank-of-india",
    },
    "CDSL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/centraldepositoryservicesltd/CDS",
        "investing_link": "https://in.investing.com/equities/central-depository-services-india",
    },
    "CENTURYPLY": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/centuryplyboards/CP9",
        "investing_link": "https://in.investing.com/equities/century-plyboards-(india)",
    },
    "CENTURYTEX": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/centurytextilesindustries/CTI",
        "investing_link": "https://in.investing.com/equities/century-textiles---industries",
    },
    "CERA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/ceramicsgranite/cerasanitaryware/CS18",
        "investing_link": "https://in.investing.com/equities/cera-sanitaryware-ltd",
    },
    "CESC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/cesc/CES",
        "investing_link": "https://in.investing.com/equities/cesc",
    },
    "CGPOWER": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/electric-equipment/cgpowerindustrialsolutions/CG",
        "investing_link": "https://in.investing.com/equities/crompton-greaves",
    },
    "CHALET": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hotels/chalethotels/CH03",
        "investing_link": "https://in.investing.com/equities/chalet-hotels-ltd",
    },
    "CHAMBLFERT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/fertilisers/chambalfertiliserschemicals/CFC",
        "investing_link": "https://in.investing.com/equities/chambal-fertilizers---chem.",
    },
    "CHEMPLASTS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/speciality-chemicals/chemplastsanmar/CS23",
        "investing_link": "https://in.investing.com/equities/chemplast-sanmar-india",
    },
    "CHOLAHLDNG": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/cholamandalamfinancialholdings/TII",
        "investing_link": "https://in.investing.com/equities/tube-investments-of-india",
    },
    "CHOLAFIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-nbfc/cholamandalaminvestmentfinancecompany/CDB",
        "investing_link": "https://in.investing.com/equities/cholamandalam-inv.-and-finance",
    },
    "CIPLA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/cipla/C",
        "investing_link": "https://in.investing.com/equities/cipla",
    },
    "CUB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/cityunionbank/CUB",
        "investing_link": "https://in.investing.com/equities/city-union-bank",
    },
    "CLEAN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/speciality-chemicals/cleansciencetechnology/CST",
        "investing_link": "https://in.investing.com/equities/clean-science-and-technology",
    },
    "COALINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miningminerals/coalindia/CI11",
        "investing_link": "https://in.investing.com/equities/coal-india",
    },
    "COCHINSHIP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/ship-building/cochinshipyard/CS",
        "investing_link": "https://in.investing.com/equities/cochin-shipyard",
    },
    "COFORGE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/coforgelimited/NII02",
        "investing_link": "https://in.investing.com/equities/niit-technologies-ltd",
    },
    "COLPAL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/personal-care/colgatepalmoliveindia/CPI",
        "investing_link": "https://in.investing.com/equities/colgate-palmolive-(india)",
    },
    "CAMS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investment/computeragemanagementservices/CAM",
        "investing_link": "https://in.investing.com/equities/computer-age-management-services",
    },
    "CONCOR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/transportlogistics/containercorporationindia/CCI",
        "investing_link": "https://in.investing.com/equities/container-corporation-of-india",
    },
    "COROMANDEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/fertilisers/coromandelinternational/CI45",
        "investing_link": "https://in.investing.com/equities/coromandel-international",
    },
    "CREDITACC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-nbfc/creditaccessgrameen/CG03",
        "investing_link": "https://in.investing.com/equities/creditaccess-grameen-ltd?cid=1090471",
    },
    "CRISIL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/crisil/CRI",
        "investing_link": "https://in.investing.com/equities/crisil",
    },
    "CROMPTON": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/electricals/cromptongreavesconsumerelectrical/CGC01",
        "investing_link": "https://in.investing.com/equities/crompton-greaves-consumer-electric",
    },
    "CSBBANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/csbbank/CB05",
        "investing_link": "https://in.investing.com/equities/csb-bank-ltd",
    },
    "CUMMINSIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/engines/cumminsindia/CI02",
        "investing_link": "https://in.investing.com/equities/cummins-india",
    },
    "CYIENT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/cyient/IE07",
        "investing_link": "https://in.investing.com/equities/infotech-enterprises",
    },
    "DABUR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/personal-care/daburindia/DI",
        "investing_link": "https://in.investing.com/equities/dabur-india",
    },
    "DALBHARAT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/dalmiabharat/OCL",
        "investing_link": "https://in.investing.com/equities/ocl-india-ltd",
    },
    "DCMSHRIRAM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/dcmshriram/DCM02",
        "investing_link": "https://in.investing.com/equities/dcm-shriram-industries-bo",
    },
    "DEEPAKNTR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/deepaknitrite/DN",
        "investing_link": "https://in.investing.com/equities/deepak-nitrite-ltd",
    },
    "DELTACORP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/deltacorp/DC11",
        "investing_link": "https://in.investing.com/equities/delta-corp",
    },
    "DEVYANI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/consumer-food/devyaniinternational/DI06",
        "investing_link": "https://in.investing.com/equities/devyani-international",
    },
    "DHANI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/dhaniservices/IS13",
        "investing_link": "https://in.investing.com/equities/indiabulls-securities",
    },
    "DBL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-civil/dilipbuildcon/DB04",
        "investing_link": "https://in.investing.com/equities/dilip-buildcon-ltd",
    },
    "DIVISLAB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/divislaboratories/DL03",
        "investing_link": "https://in.investing.com/equities/divis-laboratories",
    },
    "DIXON\r": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/electricals/dixontechnologies/DT07",
        "investing_link": "https://in.investing.com/equities/dixon-technologies",
    },
    "DLF": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/dlf/D04",
        "investing_link": "https://in.investing.com/equities/dlf",
    },
    "LALPATHLAB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/drlalpathlabs/DLP01",
        "investing_link": "https://in.investing.com/equities/dr-lal-pathlabs-ltd",
    },
    "DRREDDY": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/drreddyslaboratories/DRL",
        "investing_link": "https://in.investing.com/equities/dr-reddys-laboratories",
    },
    "EIDPARRY": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/sugar/eidparryindia/EID",
        "investing_link": "https://in.investing.com/equities/eid-parry-india",
    },
    "EASEMYTRIP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/travel-services/easytripplanners/ETP01",
        "investing_link": "https://in.investing.com/equities/easy-trip-planners-pvt",
    },
    "ECLERX": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software-mediumsmall/eclerxservices/eS06",
        "investing_link": "https://in.investing.com/equities/eclerx-services",
    },
    "EDELWEISS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-general/edelweissfinancialservices/EC01",
        "investing_link": "https://in.investing.com/equities/edelweiss-financial-services",
    },
    "EICHERMOT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-lcvshcvs/eichermotors/EM",
        "investing_link": "https://in.investing.com/equities/eicher-motors",
    },
    "EIHOTEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hotels/eih/EIH",
        "investing_link": "https://in.investing.com/equities/eih",
    },
    "ELGIEQUIP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/compressors/elgiequipments/EE01",
        "investing_link": "https://in.investing.com/equities/elgi-equipments",
    },
    "EMAMILTD": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/personal-care/emami/E06",
        "investing_link": "https://in.investing.com/equities/emami",
    },
    "ENDURANCE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-23-wheelers/endurancetechnologies/ET01",
        "investing_link": "https://in.investing.com/equities/endurance-technologies-cn-ltd",
    },
    "ENGINERSIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/engineering/engineersindia/EI14",
        "investing_link": "https://in.investing.com/equities/engineers-india",
    },
    "EPL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/packaging/epl/EP11",
        "investing_link": "https://in.investing.com/equities/essel-propack",
    },
    "EQUITAS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-general/equitasholdings/EH03",
        "investing_link": "https://in.investing.com/equities/equitas-holdings-ltd",
    },
    "EQUITASBNK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/bank-private/equitassmallfinancebank/ESF",
        "investing_link": "https://in.investing.com/equities/equitas-small-finance-bank",
    },
    "ERIS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticalsdrugs/erislifesciences/EL01",
        "investing_link": "https://in.investing.com/equities/eris-lifesciences-ltd",
    },
    "ESCORTS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/automobile-tractors/escortskubota/E",
        "investing_link": "https://in.investing.com/equities/escorts",
    },
    "EXIDEIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries/exideindustries/EI",
        "investing_link": "https://in.investing.com/equities/exide-industries",
    },
    "FDC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/fdc/FDC",
        "investing_link": "https://in.investing.com/equities/fdc",
    },
    "FEDERALBNK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/federalbank/FB",
        "investing_link": "https://in.investing.com/equities/the-federal-bank",
    },
    "FACT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/fertilisers/fertiliserschemicalstravancore/FCT",
        "investing_link": "https://in.investing.com/equities/fertilisers-chemicals-travancore",
    },
    "FINEORG": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/fineorganicsindustries/FOI",
        "investing_link": "https://in.investing.com/equities/fine-organic",
    },
    "FINCABLES": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cables-telephone/finolexcables/FC01",
        "investing_link": "https://in.investing.com/equities/finolex-cables",
    },
    "FINPIPE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/petrochemicals/finolexindustries/FI",
        "investing_link": "https://in.investing.com/equities/finolex-industries",
    },
    "FSL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software-mediumsmall/firstsourcesolutions/FS07",
        "investing_link": "https://in.investing.com/equities/firstsource-solutions",
    },
    "FORTIS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hospitalsmedical-services/fortishealthcare/FH",
        "investing_link": "https://in.investing.com/equities/fortis-healthcare-(india)",
    },
    "NYKAA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/fsne-commerceventuresnykaa/FEV",
        "investing_link": "https://in.investing.com/equities/fsn-ecommerce-ventures",
    },
    "GRINFRA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/construction-infrastructure/grinfraprojects/I09",
        "investing_link": "https://in.investing.com/equities/g-r-infraprojects",
    },
    "GAIL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/oil-drillingexploration/gailindia/GAI",
        "investing_link": "https://in.investing.com/equities/gail-(india)",
    },
    "GALAXYSURF": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/galaxysurfactantsltd/GSL06",
        "investing_link": "https://in.investing.com/equities/galaxy-surfactants-limited",
    },
    "GARFIBRES": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-general/garwaretechnicalfibres/GWR",
        "investing_link": "https://in.investing.com/equities/garware-wall-ropes-ltd",
    },
    "GICRE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/generalinsurancecorporationindia/GIC12",
        "investing_link": "https://in.investing.com/equities/general-insurance-corporation-of-in",
    },
    "GLAND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticalsdrugs/glandpharma/GP14",
        "investing_link": "https://in.investing.com/equities/gland-pharma",
    },
    "GLAXO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/glaxosmithklinepharmaceuticals/GSK",
        "investing_link": "https://in.investing.com/equities/gsk-pharmaceuticals",
    },
    "GLS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticalsdrugs/glenmarklifesciences/GLS01",
        "investing_link": "https://in.investing.com/equities/glenmark-life-sciences",
    },
    "GLENMARK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/glenmarkpharma/GP08",
        "investing_link": "https://in.investing.com/equities/glenmark-pharmaceuticals",
    },
    "GMMPFAUDLR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/engineering-heavy/gmmpfaudler/GMM01",
        "investing_link": "https://in.investing.com/equities/gmm-pfaudler",
    },
    "GMRINFRA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/transport-infrastructure/gmrairportsinfrastructure/GI27",
        "investing_link": "https://in.investing.com/equities/gmr-infrastructure",
    },
    "GOCOLORS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/retailing/gofashionindia/GFI04",
        "investing_link": "https://in.investing.com/equities/go-fashion",
    },
    "GODFRYPHLP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cigarettes/godfreyphillipsindia/GPI",
        "investing_link": "https://in.investing.com/equities/godfrey-phillips-india",
    },
    "GODREJAGRO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/godrejagrovet/GA03",
        "investing_link": "https://in.investing.com/equities/godrej-agrovet-ltd",
    },
    "GODREJCP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/personal-care/godrejconsumerproducts/GCP",
        "investing_link": "https://in.investing.com/equities/godrej-consumer-products",
    },
    "GODREJIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/personal-care/godrejindustries/GI23",
        "investing_link": "https://in.investing.com/equities/godrej-industries",
    },
    "GODREJPROP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/godrejproperties/GP11",
        "investing_link": "https://in.investing.com/equities/godrej-properties",
    },
    "GRANULES": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/granulesindia/GI25",
        "investing_link": "https://in.investing.com/equities/granules-india-ltd",
    },
    "GRAPHITE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/electrodesgraphite/graphiteindia/GI13",
        "investing_link": "https://in.investing.com/equities/graphite-india",
    },
    "GRASIM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/grasimindustries/GI01",
        "investing_link": "https://in.investing.com/equities/grasim-industries",
    },
    "GESHIP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/shipping/greateasternshippingcompany/GES",
        "investing_link": "https://in.investing.com/equities/great-eastern-shipping",
    },
    "GRINDWELL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/abrasives/grindwellnorton/GN",
        "investing_link": "https://in.investing.com/equities/grindwell-norton-ltd",
    },
    "GUJALKALI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/gujaratalkalieschemicals/GAC01",
        "investing_link": "https://in.investing.com/equities/gujarat-alkalies-and-chemicals",
    },
    "GAEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/food-processing/gujaratambujaexports/GAE",
        "investing_link": "https://in.investing.com/equities/gujarat-ambuja-exports",
    },
    "FLUOROCHEM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/gujaratfluorochemicalslimited/GUJAR54281",
        "investing_link": "https://in.investing.com/equities/gujarat-fluorochemicals",
    },
    "GUJGASLTD": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/oil-drillingexploration/gujaratgas/GGC",
        "investing_link": "https://in.investing.com/equities/gujarat-fluorochemicals",
    },
    "GNFC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/fertilizers/gujaratnarmadavalleyfertchem/GNV",
        "investing_link": "https://in.investing.com/equities/gujarat-narmada-valley-fert.",
    },
    "GPPL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/shipping/gujaratpipavavport/GPP03",
        "investing_link": "https://in.investing.com/equities/gujarat-pipavav-port",
    },
    "GSFC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/fertilisers/gujaratstatefertilizerschemicals/GSF",
        "investing_link": "https://in.investing.com/equities/gujarat-state-fertil.---chem.",
    },
    "GSPL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/oil-drillingexploration/gujaratstatepetronet/GSP02",
        "investing_link": "https://in.investing.com/equities/gujarat-state-petronet",
    },
    "HEG": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/electrodesgraphite/heg/HEG",
        "investing_link": "https://in.investing.com/equities/heg",
    },
    "HAPPSTMNDS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/happiestmindstechnologiesltd/HMT01",
        "investing_link": "https://in.investing.com/equities/happiest-minds-technologies-ltd",
    },
    "HATHWAY": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/mediaentertainment/hathwaycabledatacom/HCD",
        "investing_link": "https://in.investing.com/equities/hathway-cable---datacom",
    },
    "HATSUN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/food-processing/hatsunagroproducts/HAP",
        "investing_link": "https://in.investing.com/equities/hatsun-agro-product-ltd",
    },
    "HAVELLS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/electric-equipment/havellsindia/HI01",
        "investing_link": "https://in.investing.com/equities/havells-india",
    },
    "HCLTECH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/hcltechnologies/HCL02",
        "investing_link": "https://in.investing.com/equities/hcl-technologies",
    },
    "HDFCAMC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/hdfcassetmanagementcompany/HAM02",
        "investing_link": "https://in.investing.com/equities/hdfc-asset-management-company-ltd",
    },
    "HDFCBANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/hdfcbank/HDF01",
        "investing_link": "https://in.investing.com/equities/hdfc-bank-ltd",
    },
    "HDFCLIFE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/lifehealth-insurance/hdfclifeinsurancecompany/HSL01",
        "investing_link": "https://in.investing.com/equities/hdfc-standard-life",
    },
    "HEMIPROP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/construction-real-estate/hemispherepropertiesindia/HPI01",
        "investing_link": "https://in.investing.com/equities/hemisphere-properties-ns",
    },
    "HEROMOTOCO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-23-wheelers/heromotocorp/HHM",
        "investing_link": "https://in.investing.com/equities/hero-motocorp",
    },
    "HFCL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/telecommunications-equipment/hfcl/HFC",
        "investing_link": "https://in.investing.com/equities/himachal-futuristic-comm.",
    },
    "HIKAL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/hikal/H05",
        "investing_link": "https://in.investing.com/equities/hikal-ltd",
    },
    "HINDALCO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/ironsteel/hindalcoindustries/HI",
        "investing_link": "https://in.investing.com/equities/hindalco-industries",
    },
    "HGS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/hindujaglobalsolutions/HGS01",
        "investing_link": "https://in.investing.com/equities/hinduja-global-solutions-ltd",
    },
    "HAL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/hindustanaeronauticsltd/HAL",
        "investing_link": "https://in.investing.com/equities/hindustan-aeronautics-ltd",
    },
    "HINDCOPPER": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/metals-non-ferrous/hindustancopper/HC07",
        "investing_link": "https://in.investing.com/equities/hindustan-copper-ltd",
    },
    "HINDPETRO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/refineries/hindustanpetroleumcorporation/HPC",
        "investing_link": "https://in.investing.com/equities/hindustan-petroleum",
    },
    "HINDUNILVR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/personal-care/hindustanunilever/HU",
        "investing_link": "https://in.investing.com/equities/hindustan-unilever",
    },
    "HINDZINC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/metals-non-ferrous/hindustanzinc/HZ",
        "investing_link": "https://in.investing.com/equities/hindustan-zinc",
    },
    "POWERINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/electric-equipment/hitachienergyindia/APP03",
        "investing_link": "https://in.investing.com/equities/abb-power-products-and-systems",
    },
    "HLEGLAS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/glassglass-products/hleglascoat/SGE02",
        "investing_link": "https://in.investing.com/equities/swiss-glascoat-equipments-bo",
    },
    "HOMEFIRST": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-housing/homefirstfinancecompanyindia/HFF",
        "investing_link": "https://in.investing.com/equities/home-first-finance-india",
    },
    "HONAUT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/telecommunications-equipment/honeywellautomation/HA04",
        "investing_link": "https://in.investing.com/equities/honeywell-automation-india",
    },
    "HUDCO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/housingurbandevelopmentcorporation/HUD",
        "investing_link": "https://in.investing.com/equities/housing-and-urban-development",
    },
    "HDFC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-housing/housingdevelopmentfinancecorporation/HDF",
        "investing_link": "https://in.investing.com/equities/housing-development-finance",
    },
    "ICICIBANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/icicibank/ICI02",
        "investing_link": "https://in.investing.com/equities/icici-bank-ltd",
    },
    "ICICIGI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/multiline-insurancebrokers/icicilombardgeneralinsurancecompany/ILG",
        "investing_link": "https://in.investing.com/equities/icici-lombard",
    },
    "ICICIPRULI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-general/iciciprudentiallifeinsurancecompany/IPL01",
        "investing_link": "https://in.investing.com/equities/icici-prudential-life-insurance-com",
    },
    "ISEC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/icicisecuritiesltd/ISL04",
        "investing_link": "https://in.investing.com/equities/icici-securities-ltd",
    },
    "IDBI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/bank-private/idbibank/IDB05",
        "investing_link": "https://in.investing.com/equities/idbi-bank",
    },
    "IDFCFIRSTB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/idfcfirstbank/IDF01",
        "investing_link": "https://in.investing.com/equities/idfc-bank-ltd",
    },
    "IDFC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-housing/idfc/IDF",
        "investing_link": "https://in.investing.com/equities/idfc-limited",
    },
    "IFBIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/consumer-goods-white-goods/ifbindustries/IFB02",
        "investing_link": "https://in.investing.com/equities/ifb-industries-ltd",
    },
    "IIFL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-general/iiflfinance/II15",
        "investing_link": "https://in.investing.com/equities/india-infoline-limited",
    },
    "360ONE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-others/360onewam/IIFLW54277",
        "investing_link": "https://in.investing.com/equities/iifl-wealth-management-ltd",
    },
    "INDIACEM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/indiacements/IC",
        "investing_link": "https://in.investing.com/equities/the-india-cements-limited",
    },
    "IBULHSGFIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-housing/indiabullshousingfinance/IHF01",
        "investing_link": "https://in.investing.com/equities/indiabulls",
    },
    "IBREALEST": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/indiabullsrealestate/IRE01",
        "investing_link": "https://in.investing.com/equities/indiabulls-real-estate-ltd",
    },
    "INDIAMART": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/indiamartintermesh/II12",
        "investing_link": "https://in.investing.com/equities/indiamart-intermesh-ltd?cid=1161582",
    },
    "INDIANB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/indianbank/IB04",
        "investing_link": "https://in.investing.com/equities/indian-bank",
    },
    "IEX": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/indianenergyexchange/IEE",
        "investing_link": "https://in.investing.com/equities/indian-energy-exchange-ltd",
    },
    "INDHOTEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hotels/indianhotelscompany/IHC",
        "investing_link": "https://in.investing.com/equities/the-indian-hotels",
    },
    "IOC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/refineries/indianoilcorporation/IOC",
        "investing_link": "https://in.investing.com/equities/indian-oil-corporation",
    },
    "IOB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/indianoverseasbank/IOB",
        "investing_link": "https://in.investing.com/equities/indian-overseas-bank",
    },
    "IRCTC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/irctc-indianrailwaycateringtourismcorp/IRC",
        "investing_link": "https://in.investing.com/equities/indian-railway-catering-and-tourism",
    },
    "IRFC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-nbfc/indianrailwayfinancecorporation/IRF",
        "investing_link": "https://in.investing.com/equities/indian-railway-finance",
    },
    "INDIGOPNTS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/paints/indigopaints/IP08",
        "investing_link": "https://in.investing.com/equities/indigo-paints-pvt",
    },
    "ICIL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-spinning-cotton-blended/indocountindustries/ICI07",
        "investing_link": "https://in.investing.com/equities/indo-count-industries-ltd",
    },
    "INDOCO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/indocoremedies/IR05",
        "investing_link": "https://in.investing.com/equities/indoco-remedies-ltd",
    },
    "IGL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/oil-drillingexploration/indraprasthagas/IG04",
        "investing_link": "https://in.investing.com/equities/indraprastha-gas",
    },
    "INDUSTOWER": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/telecommunications-equipment/industowers/BI14",
        "investing_link": "https://in.investing.com/equities/bharti-infratel-ltd",
    },
    "INDUSINDBK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/indusindbank/IIB",
        "investing_link": "https://in.investing.com/equities/indusind-bank",
    },
    "INFIBEAM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/online-services/infibeamavenues/IIL03",
        "investing_link": "https://in.investing.com/equities/infibeam-incorporation",
    },
    "NAUKRI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/infoedgeindia/IEI01",
        "investing_link": "https://in.investing.com/equities/info-edge-(india)",
    },
    "INFY": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/infosys/IT",
        "investing_link": "https://in.investing.com/equities/infosys",
    },
    "INOXLEISUR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/mediaentertainment/inoxleisure/INO01",
        "investing_link": "https://in.investing.com/equities/pvrl",
    },
    "INTELLECT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/intellectdesignarena/IDA",
        "investing_link": "https://in.investing.com/equities/intellect-design-arena-ltd",
    },
    "INDIGO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/transportlogistics/interglobeaviation/IA04",
        "investing_link": "https://in.investing.com/equities/interglobe-aviation-ltd",
    },
    "IPCALAB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/ipcalaboratories/IL",
        "investing_link": "https://in.investing.com/equities/ipca-laboratories",
    },
    "IRB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/infrastructure-general/irbinfrastructuredevelopers/IID01",
        "investing_link": "https://in.investing.com/equities/irb-infrastructure-developers",
    },
    "IRCON": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/engineering-heavy/irconinternational/II07",
        "investing_link": "https://in.investing.com/equities/ircon-international",
    },
    "ITC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/itc/ITC",
        "investing_link": "https://in.investing.com/equities/itc",
    },
    "ITI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/itc/ITC",
        "investing_link": "https://in.investing.com/equities/iti-ltd",
    },
    "JBCHEPHARM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/jbchemicalspharmaceuticals/JBC01",
        "investing_link": "https://in.investing.com/equities/jb-chemicals---pharmaceuticals",
    },
    "JKCEMENT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/jkcement/JKC03",
        "investing_link": "https://in.investing.com/equities/j.k.-cement-ltd",
    },
    "JAMNAAUTO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries/jamnaautoindustries/JAI",
        "investing_link": "https://in.investing.com/equities/jamna-auto-industries-ltd",
    },
    "JSL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/steel-mediumsmall/jindalstainless/JSL01",
        "investing_link": "https://in.investing.com/equities/jindal-stainless",
    },
    "JINDALSTEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/steel-sponge-iron/jindalsteelpower/JSP",
        "investing_link": "https://in.investing.com/equities/jindal-steel---power",
    },
    "JKLAKSHMI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/jklakshmicement/JKL01",
        "investing_link": "https://in.investing.com/equities/jk-lakshmi-cement-ltd",
    },
    "JKPAPER": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/paper/jkpaper/JKP01",
        "investing_link": "https://in.investing.com/equities/jk-paper-ltd",
    },
    "JMFINANCIL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/jmfinancial/JMF",
        "investing_link": "https://in.investing.com/equities/jm-financial",
    },
    "JSWENERGY": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/jswenergy/JE01",
        "investing_link": "https://in.investing.com/equities/jsw-energy",
    },
    "JSWSTEEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/steel-large/jswsteel/JSW01",
        "investing_link": "https://in.investing.com/equities/jsw-steel",
    },
    "JUBLFOOD": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/jubilantfoodworks/JF04",
        "investing_link": "https://in.investing.com/equities/jubilant-foodworks",
    },
    "JUBLINGREA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/speciality-chemicals/jubilantingrevia/JI14",
        "investing_link": "https://in.investing.com/equities/jubilant-ingrevia",
    },
    "JUBLPHARMA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/jubilantpharmova/JO03",
        "investing_link": "https://in.investing.com/equities/jubilant-life-sciences",
    },
    "JUSTDIAL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/justdial/JD",
        "investing_link": "https://in.investing.com/equities/just-dial-ltd",
    },
    "JYOTHYLAB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/personal-care/jyothylabs/JL",
        "investing_link": "https://in.investing.com/equities/jyothy-laboratories-ltd",
    },
    "KPRMILL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-readymade-apparels/kprmill/M15",
        "investing_link": "https://in.investing.com/equities/kpr-mill-ltd",
    },
    "KAJARIACER": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/ceramicsgranite/kajariaceramics/KC06",
        "investing_link": "https://in.investing.com/equities/kajaria-ceramics",
    },
    "KAPT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-transmissionequipment/kalpataruprojectsinternational/KPT",
        "investing_link": "https://in.investing.com/equities/kalpataru-power-transmission",
    },
    "KALYANKJIL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diamondjewellery/kalyanjewellersindia/KJI01",
        "investing_link": "https://in.investing.com/equities/kalyan-jewellers-india",
    },
    "KANSAINER": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/paintsvarnishes/kansainerolacpaints/KNP",
        "investing_link": "https://in.investing.com/equities/kansai-nerolac-paints",
    },
    "KARURVYSYA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/karurvysyabank/KVB",
        "investing_link": "https://in.investing.com/equities/karur-vysya-bank",
    },
    "KEC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-transmissionequipment/kecinternational/KEC04",
        "investing_link": "https://in.investing.com/equities/kec-international",
    },
    "KEI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cables-powerothers/keiindustries/KEI",
        "investing_link": "https://in.investing.com/equities/kei-industries-ltd",
    },
    "KNRCON": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-civil/knrconstructions/KC13",
        "investing_link": "https://in.investing.com/equities/knr-constructions-ltd",
    },
    "KOTAKBANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/kotakmahindrabank/KMB",
        "investing_link": "https://in.investing.com/equities/kotak-mahindra-bank",
    },
    "KPITTECH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/it-servicesconsulting/kpittechnologies/KPITT54265",
        "investing_link": "https://in.investing.com/equities/kpit-tech",
    },
    "KRBL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/food-processing/krbl/KRB01",
        "investing_link": "https://in.investing.com/equities/krbl-ltd",
    },
    "KIMS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hospitalhealthcare-services/krishnainstitutemedicalsciences/KIo01",
        "investing_link": "https://in.investing.com/equities/krishna-institute-medical-sciences",
    },
    "L&TFH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/ltfinanceholdings/LFH",
        "investing_link": "https://in.investing.com/equities/lt-finance-holdings-ltd",
    },
    "LTTS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/engineering/lttechnologyservices/LTS",
        "investing_link": "https://in.investing.com/equities/lt-technology-services-ltd-ns",
    },
    "LAXMIMACH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-machinery/lakshmimachineworks/LMW",
        "investing_link": "https://in.investing.com/equities/lakshmi-machine-works",
    },
    "LTIM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/ltimindtree/LI12",
        "investing_link": "https://in.investing.com/equities/larsen-toubro-infotech-ltd",
    },
    "LT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/infrastructure-general/larsentoubro/LT",
        "investing_link": "https://in.investing.com/equities/larsen---toubro",
    },
    "LATENTVIEW": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/it-servicesconsulting/latentviewanalytics/LVA",
        "investing_link": "https://in.investing.com/equities/latent-view-analytics-ltd",
    },
    "LAURUSLABS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/lauruslabs/LL05",
        "investing_link": "https://in.investing.com/equities/laurus-labs-ltd",
    },
    "LXCHEM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/speciality-chemicals/laxmiorganicindustries/LOI",
        "investing_link": "https://in.investing.com/equities/laxmi-organic-co",
    },
    "LICHSGFIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-housing/lichousingfinance/LIC",
        "investing_link": "https://in.investing.com/equities/lic-housing-finance",
    },
    "LINDEINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/lindeindia/BOC",
        "investing_link": "https://in.investing.com/equities/boc-india",
    },
    "LUPIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/lupin/L",
        "investing_link": "https://in.investing.com/equities/lupin",
    },
    "LUXIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-processing/luxindustries/LHI",
        "investing_link": "https://in.investing.com/equities/lux-industries-ltd",
    },
    "LODHA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/construction-residentialcommercial-complexes/macrotechdevelopers/MD03",
        "investing_link": "https://in.investing.com/equities/macrotech-developers-bo",
    },
    "MGL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/refineries/mahanagargas/MG02",
        "investing_link": "https://in.investing.com/equities/mahanagar-gas-ltd-ns",
    },
    "M&MFIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-nbfc/mahindramahindrafinancialservices/MMF04",
        "investing_link": "https://in.investing.com/equities/mahindra---mahindra-financials",
    },
    "M&M": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-carsjeeps/mahindramahindra/MM",
        "investing_link": "https://in.investing.com/equities/mahindra---mahindra",
    },
    "CIE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries-castingsforgings/cieautomotiveindia/MF19",
        "investing_link": "https://in.investing.com/equities/mahindra-cie-automotive-ltd",
    },
    "MHRIL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hotels/mahindraholidaysresortsindia/MHR",
        "investing_link": "https://in.investing.com/equities/mahindra-holidays-resorts-india",
    },
    "MAHLOG": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/mahindralogistics/ML04",
        "investing_link": "https://in.investing.com/equities/mahindra-logistics-ltd",
    },
    "MANAPPURAM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-leasinghire-purchase/manappuramfinance/MGF01",
        "investing_link": "https://in.investing.com/equities/manappuram-finance-ltd",
    },
    "MRPL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/refineries/mangalorerefinerypetrochemicals/MRP",
        "investing_link": "https://in.investing.com/equities/mangalore-refinery-and-petro.",
    },
    "MARICO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/personal-care/marico/M13",
        "investing_link": "https://in.investing.com/equities/marico",
    },
    "MARUTI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-carsjeeps/marutisuzukiindia/MS24",
        "investing_link": "https://in.investing.com/equities/maruti-suzuki-india",
    },
    "MASTEK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/mastek/M",
        "investing_link": "https://in.investing.com/equities/mastek",
    },
    "MFSL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/maxfinancialservices/MI",
        "investing_link": "https://in.investing.com/equities/max-india",
    },
    "MAXHEALTH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hospitalhealthcare-services/maxhealthcareinstitutelimited/MHI",
        "investing_link": "https://in.investing.com/equities/max-healthcare-institute-ns",
    },
    "MAZDOCK\r": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/ship-building/mazagondockshipbuilders/MDS01",
        "investing_link": "https://in.investing.com/equities/mazagon-dock-shipbuilders",
    },
    "MEDPLUS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/fooddrug-retailing/medplushealthservices/MHS01",
        "investing_link": "https://in.investing.com/equities/medplus-health-services",
    },
    "METROBRAND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/footwear/metrobrands/MB06",
        "investing_link": "https://in.investing.com/equities/metro-brands?cid=1182955",
    },
    "METROPOLIS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hospitalsmedical-services/metropolishealthcare/MH06",
        "investing_link": "https://in.investing.com/equities/metropolis-healthcare-ltd",
    },
    "UNOMINDA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries/mindaindustries-re/MIL18",
        "investing_link": "https://in.investing.com/equities/minda-corp",
    },
    "NaN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-leasinghire-purchase/shriramcityunionfinance/SCU",
        "investing_link": "https://in.investing.com/equities/shriram-city-union-finance-ltd",
    },
    "MMTC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/trading/mmtc/MMT",
        "investing_link": "https://in.investing.com/equities/mmtc-ltd",
    },
    "MOIL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miningminerals/moil/M18",
        "investing_link": "https://in.investing.com/equities/moil-ltd",
    },
    "MOTILALOFS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-general/motilaloswalfinancialservices/MOF01",
        "investing_link": "https://in.investing.com/equities/motilal-oswal-financials",
    },
    "MPHASIS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/mphasis/MB02",
        "investing_link": "https://in.investing.com/equities/mphasis",
    },
    "MRF": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/tyres/mrf/MRF",
        "investing_link": "https://in.investing.com/equities/mrf",
    },
    "MTARTECH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/aerospacedefence/mtartechnologies/MT15",
        "investing_link": "https://in.investing.com/equities/mtar-technologies-pvt",
    },
    "MCX": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/multicommodityexchangeindia/MCE",
        "investing_link": "https://in.investing.com/equities/multi-commodity-exchange-of-india",
    },
    "MUTHOOTFIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/muthootfinance/MF10",
        "investing_link": "https://in.investing.com/equities/muthoot-finance-ltd",
    },
    "NH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hospitalsmedical-services/narayanahrudayalaya/NH",
        "investing_link": "https://in.investing.com/equities/narayana-hrudayalaya-ltd",
    },
    "NATCOPHARM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/natcopharma/NP07",
        "investing_link": "https://in.investing.com/equities/natco-pharma-ltd",
    },
    "NATIONALUM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/aluminium/nationalaluminiumcompany/NAC",
        "investing_link": "https://in.investing.com/equities/national-aluminium",
    },
    "NAVINFLUOR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/navinfluorineinternational/NFI",
        "investing_link": "https://in.investing.com/equities/navin-fluorine-international",
    },
    "NAZARA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/software/nazaratechnologies/NT",
        "investing_link": "https://in.investing.com/equities/nazara-technologies",
    },
    "NBCC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/infrastructure-general/nbccindia/NBC01",
        "investing_link": "https://in.investing.com/equities/national-bu",
    },
    "NCC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-civil/ncc/NCC01",
        "investing_link": "https://in.investing.com/equities/ncc",
    },
    "NESCO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/nesco/NES",
        "investing_link": "https://in.investing.com/equities/nesco-ltd",
    },
    "NESTLEIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/food-processing/nestleindia/NI",
        "investing_link": "https://in.investing.com/equities/nestle",
    },
    "NETWORK18": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/mediaentertainment/network18mediainvestments/NMI",
        "investing_link": "https://in.investing.com/equities/network18-media---investments",
    },
    "NHPC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/nhpc/N07",
        "investing_link": "https://in.investing.com/equities/nhpc",
    },
    "NAM-INDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/nipponlifeindiaassetmanagement/RNL",
        "investing_link": "https://in.investing.com/equities/reliance-nippon-life",
    },
    "NLCINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/nlcindia/NLC",
        "investing_link": "https://in.investing.com/equities/neyveli-lignite-corporation",
    },
    "NMDC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miningminerals/nmdc/NMD02",
        "investing_link": "https://in.investing.com/equities/nmdc",
    },
    "NOCIL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/petrochemicals/nocil/NOC02",
        "investing_link": "https://in.investing.com/equities/nocil-ltd",
    },
    "NTPC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/ntpc/NTP",
        "investing_link": "https://in.investing.com/equities/ntpc",
    },
    "NUVOCO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement/nuvocovistascorporation/NVC",
        "investing_link": "https://in.investing.com/equities/nuvoco-vistas",
    },
    "OBEROIRLTY": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/oberoirealty/OR",
        "investing_link": "https://in.investing.com/equities/oberoi-realty",
    },
    "ONGC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/oil-drillingexploration/oilnaturalgascorporation/ONG",
        "investing_link": "https://in.investing.com/equities/oil---natural-gas-corporation",
    },
    "OIL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/oil-drillingexploration/oilindia/OI13",
        "investing_link": "https://in.investing.com/equities/oil-india",
    },
    "PAYTM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/online-services/one97communicationspaytm/OC03",
        "investing_link": "https://in.investing.com/equities/one-97-communications",
    },
    "OFSS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/oraclefinancialservicessoftware/OFS01",
        "investing_link": "https://in.investing.com/equities/oracle-financial-software",
    },
    "ORIENTELEC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/consumer-goods-electronic/orientelectriclimited/ORIEN54130",
        "investing_link": "https://in.investing.com/equities/orient-electric",
    },
    "PAGEIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-readymade-apparels/pageindustries/PI35",
        "investing_link": "https://in.investing.com/equities/page-industries",
    },
    "POLICYBZR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/multiline-insurancebrokers/pbfintech/PF14",
        "investing_link": "https://in.investing.com/equities/pb-fintech",
    },
    "PCBL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/carbon-black/pcbl/PCB01",
        "investing_link": "https://in.investing.com/equities/phillips-carbon-black-ltd",
    },
    "PERSISTENT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/carbon-black/pcbl/PCB01",
        "investing_link": "https://in.investing.com/equities/persistent-systems",
    },
    "PETRONET": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/oil-drillingexploration/petronetlng/PLN",
        "investing_link": "https://in.investing.com/equities/petronet-lng",
    },
    "PFIZER": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/pfizer/P",
        "investing_link": "https://in.investing.com/equities/pfizer-ltd",
    },
    "PHOENIXLTD": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/phoenixmills/PM02",
        "investing_link": "https://in.investing.com/equities/the-phoenix-mills",
    },
    "PIIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pesticidesagro-chemicals/piindustries/PII",
        "investing_link": "https://in.investing.com/equities/p-i-industr",
    },
    "PIDILITIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/pidiliteindustries/PI11",
        "investing_link": "https://in.investing.com/equities/pidilite-industries",
    },
    "PEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-nbfc/piramalenterprises/PH05",
        "investing_link": "https://in.investing.com/equities/piramal-healthcare",
    },
    "PNBHOUSING": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-housing/pnbhousingfinance/PHF",
        "investing_link": "https://in.investing.com/equities/pnb-housing-finance-ltd",
    },
    "PNCINFRA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/pncinfratech/PI26",
        "investing_link": "https://in.investing.com/equities/pnc-infratech-ltd",
    },
    "POLYMED": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hospitalsmedical-services/polymedicure/PM06",
        "investing_link": "https://in.investing.com/equities/poly-medicure-ltd",
    },
    "POLYCAB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cables-powerothers/polycabindia/PI44",
        "investing_link": "https://in.investing.com/equities/polycab-india-ltd",
    },
    "POLYPLEX": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/packaging/polyplexcorporation/PC08",
        "investing_link": "https://in.investing.com/equities/polyplex-corporation-ltd",
    },
    "POONAWALLA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-nbfc/poonawallafincorp/MF20",
        "investing_link": "https://in.investing.com/equities/magma-fincorp-ltd",
    },
    "PFC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-term-lending-institutions/powerfinancecorporation/PFC02",
        "investing_link": "https://in.investing.com/equities/power-finance-corporation",
    },
    "POWERGRID": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/powergridcorporationindia/PGC",
        "investing_link": "https://in.investing.com/equities/power-grid-corp.-of-india",
    },
    "PRAJIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/engineering-heavy/prajindustries/PI17",
        "investing_link": "https://in.investing.com/equities/praj-industries",
    },
    "PRESTIGE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/prestigeestatesprojects/PEP02",
        "investing_link": "https://in.investing.com/equities/prestige-estates-projects",
    },
    "PRINCEPIPE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/plastics-tubespipeshosesfittings/princepipesfittings/PPF",
        "investing_link": "https://in.investing.com/equities/prince-pipes-and-fittings-ltd",
    },
    "PRSMJOHNSN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/prismjohnson/PC",
        "investing_link": "https://in.investing.com/equities/prism-cement",
    },
    "PRIVISCL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/privispecialitychemicals/HKF",
        "investing_link": "https://in.investing.com/equities/adi-finechem",
    },
    "PGHL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/proctergamblehealth/M12",
        "investing_link": "https://in.investing.com/equities/merck",
    },
    "PGHH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/personal-care/proctergamblehygienehealthcare/PGH",
        "investing_link": "https://in.investing.com/equities/procter-gamble-hygiene",
    },
    "PNB": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/punjabnationalbank/PNB05",
        "investing_link": "https://in.investing.com/equities/punjab-national-bank",
    },
    "PVRINOX": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/mediaentertainment/pvrinox/PVR",
        "investing_link": "https://in.investing.com/equities/pvrl",
    },
    "QUESS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/engineering/quesscorp/QC",
        "investing_link": "https://in.investing.com/equities/quess-corp-ltd-ns",
    },
    "RADICO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/breweriesdistilleries/radicokhaitan/RK01",
        "investing_link": "https://in.investing.com/equities/radico-khaitan",
    },
    "RVNL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/railvikasnigam/RVN",
        "investing_link": "https://in.investing.com/equities/rail-vikas-nigam-ltd",
    },
    "RAILTEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/telecommunications-services/railtelcorporationindia/RCo01",
        "investing_link": "https://in.investing.com/equities/railtel-corp-india",
    },
    "RAIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/rainindustries/RC12",
        "investing_link": "https://in.investing.com/equities/rain-commodities-ltd",
    },
    "RAJESHEXPO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diamond-cuttingjewelleryprecious-metals/rajeshexports/RE07",
        "investing_link": "https://in.investing.com/equities/rajesh-exports",
    },
    "RALLIS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pesticidesagro-chemicals/rallisindia/RI03",
        "investing_link": "https://in.investing.com/equities/rallis-india",
    },
    "RCF": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/fertilisers/rashtriyachemicalsfertilisers/RCF01",
        "investing_link": "https://in.investing.com/equities/rashtriya-chem.-and-fertil.",
    },
    "RATNAMANI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/steel-tubespipes/ratnamanimetalstubes/RMT",
        "investing_link": "https://in.investing.com/equities/ratnamani-metals-tubes-ltd",
    },
    "RTNINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/rattanindiaenterprises/IIP",
        "investing_link": "https://in.investing.com/equities/rattanindia-infrastructure-ltd",
    },
    "RBLBANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/rblbank/RB03",
        "investing_link": "https://in.investing.com/equities/rbl-bank-ltd",
    },
    "RECLTD": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-term-lending-institutions/rec/REC02",
        "investing_link": "https://in.investing.com/equities/rural-electrification",
    },
    "REDINGTON": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-hardware/redington/RI37",
        "investing_link": "https://in.investing.com/equities/redington-(india)",
    },
    "RELAXO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/leather-products/relaxofootwears/RF07",
        "investing_link": "https://in.investing.com/equities/relaxo-footwears-ltd",
    },
    "RELIANCE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/refineries/relianceindustries/RI",
        "investing_link": "https://in.investing.com/equities/reliance-industries",
    },
    "RBA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/consumer-food/restaurantbrandsasia/BKI01",
        "investing_link": "https://in.investing.com/equities/burger-king-india",
    },
    "RHIM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-productsbuilding-materials/rhimagnesitaindia/OR01",
        "investing_link": "https://in.investing.com/equities/orient-refractories-ltd",
    },
    "RITES": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/transport-infrastructure/rites/R02",
        "investing_link": "https://in.investing.com/equities/rites",
    },
    "ROSSARI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/speciality-chemicals/rossaribiotech/RB05",
        "investing_link": "https://in.investing.com/equities/rossari-biotech-ltd",
    },
    "ROUTE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/it-servicesconsulting/routemobileltd/RML02",
        "investing_link": "https://in.investing.com/equities/route-mobile-ltd",
    },
    "SANOFI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/sanofiindia/AP26",
        "investing_link": "https://in.investing.com/equities/sanofi-india-ltd",
    },
    "SAPPHIRE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hotel-resortrestaurants/sapphirefoodsindia/SFI05",
        "investing_link": "https://in.investing.com/equities/sapphire-foods-india-bo?cid=1179517",
    },
    "SAREGAMA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/mediaentertainment/saregamaindia/SI67",
        "investing_link": "https://in.investing.com/equities/saregama-india-ltd",
    },
    "SBICARD": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-term-lending/sbicardspaymentservices/SCP02",
        "investing_link": "https://in.investing.com/equities/sbi-cards-and-payment-services-ltd",
    },
    "SBILIFE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/lifehealth-insurance/sbilifeinsurancecompany/SLI03",
        "investing_link": "https://in.investing.com/equities/sbi-life-insurance",
    },
    "SCHAEFFLER": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/bearings/schaefflerindia/FAG",
        "investing_link": "https://in.investing.com/equities/fag-bearings-india",
    },
    "SEQUENT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/sequentscientific/PID01",
        "investing_link": "https://in.investing.com/equities/sequent-scientific",
    },
    "SFL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/sheelafoam/SF14",
        "investing_link": "https://in.investing.com/equities/sheela-foam-ltd",
    },
    "SHILPAMED": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/shilpamedicare/SM19",
        "investing_link": "https://in.investing.com/equities/shilpa-medicare-ltd",
    },
    "SCI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/shipping/shippingcorporationindia/SCI",
        "investing_link": "https://in.investing.com/equities/shipping-corporation-of-india",
    },
    "SHREECEM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/shreecements/SC12",
        "investing_link": "https://in.investing.com/equities/shree-cements",
    },
    "RENUKA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/sugar/shreerenukasugars/SRS03",
        "investing_link": "https://in.investing.com/equities/shree-renuka-sugars",
    },
    "SHRIRAMFIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-leasinghire-purchase/shriramtransportfinancecompany-re/STF01",
        "investing_link": "https://in.investing.com/equities/shriram-transport-finance",
    },
    "SHYAMMETL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/ironsteel/shyammetalicsenergy/SME05",
        "investing_link": "https://in.investing.com/equities/shyam-metalics-and-energy",
    },
    "SIEMENS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/infrastructure-general/siemens/S",
        "investing_link": "https://in.investing.com/equities/siemens-ltd",
    },
    "SIS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/sis/SIS08",
        "investing_link": "https://in.investing.com/equities/security-and-intelligence",
    },
    "SJVN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/sjvn/S11",
        "investing_link": "https://in.investing.com/equities/sjvn-ltd",
    },
    "SKFINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/bearings/skfindia/SKF01",
        "investing_link": "https://in.investing.com/equities/skf-india",
    },
    "SOBHA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/sobha/SD6",
        "investing_link": "https://in.investing.com/equities/sobha-developers",
    },
    "SOLARINDS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/solarindustriesindia/SII04",
        "investing_link": "https://in.investing.com/equities/solar-industries-india-ltd",
    },
    "SOLARA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/solaraactivepharmasciences/SOLAR54154",
        "investing_link": "https://in.investing.com/equities/solara-active-pharma",
    },
    "SONACOMS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries-castingsforgings/sonablwprecisionforgings/SBP04",
        "investing_link": "https://in.investing.com/equities/sona-blw-precision-forgings-ltd",
    },
    "SONATSOFTW": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software-mediumsmall/sonatasoftware/SS42",
        "investing_link": "https://in.investing.com/equities/sonata-software",
    },
    "SPICEJET": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/transportlogistics/spicejet/SJ01",
        "investing_link": "https://in.investing.com/equities/spicejet-ltd-bse",
    },
    "SRF": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/srf/SRF",
        "investing_link": "https://in.investing.com/equities/srf",
    },
    "STARHEALTH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/starhealthalliedinsurancecompany/SHA",
        "investing_link": "https://in.investing.com/equities/star-health-and-allied-insurance-ns",
    },
    "SBIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/statebankindia/SBI",
        "investing_link": "https://in.investing.com/equities/state-bank-of-india",
    },
    "SAIL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/steel-large/steelauthorityindia/SAI",
        "investing_link": "https://in.investing.com/equities/steel-authority-of-india",
    },
    "SWSOLAR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/sterlingwilsonrenewableenergy/SWS",
        "investing_link": "https://in.investing.com/equities/sterling-and-wilson-solar-ltd",
    },
    "STLTECH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cables-telephone/sterlitetechnologies/ST20",
        "investing_link": "https://in.investing.com/equities/sterlite-technologies",
    },
    "STAR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/stridespharmascience/SA10",
        "investing_link": "https://in.investing.com/equities/strides-arcolab",
    },
    "SUDARSCHEM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/dyespigments/sudarshanchemicalindustries/SCI08",
        "investing_link": "https://in.investing.com/equities/sudarshan-chemical-industries",
    },
    "SUMICHEM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pesticidesagrochemicals/sumitomochemicalindialimite/SUMIC54292",
        "investing_link": "https://in.investing.com/equities/sumitomo-chemical-india-ltd",
    },
    "SPARC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/sunpharmaadvancedresearchcompany/SPA",
        "investing_link": "https://in.investing.com/equities/sun-pharma-adv.-research",
    },
    "SUNPHARMA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/sunpharmaceuticalindustries/SPI",
        "investing_link": "https://in.investing.com/equities/sun-pharma-advanced-research",
    },
    "SUNTV": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/mediaentertainment/suntvnetwork/STN01",
        "investing_link": "https://in.investing.com/equities/sun-tv-network",
    },
    "SUNDARMFIN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-leasinghire-purchase/sundaramfinance/SF20",
        "investing_link": "https://in.investing.com/equities/sundaram-finance",
    },
    "SUNDRMFAST": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/fasteners/sundramfasteners/SF23",
        "investing_link": "https://in.investing.com/equities/sundaram-finance",
    },
    "SUNTECK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/constructioncontracting-real-estate/sunteckrealty/SR05",
        "investing_link": "https://in.investing.com/equities/sunteck-realty",
    },
    "SUPRAJIT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries/suprajitengineering/SE15",
        "investing_link": "https://in.investing.com/equities/suprajit-engineering-ltd",
    },
    "SUPREMEIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/plastics/supremeindustries/SI48",
        "investing_link": "https://in.investing.com/equities/supreme-industries",
    },
    "SUVENPHAR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticalsdrugs/suvenpharmaceuticals/SP19",
        "investing_link": "https://in.investing.com/equities/suven-pharmaceuticals-ltd",
    },
    "SUZLON": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/suzlonenergy/SE17",
        "investing_link": "https://in.investing.com/equities/suzlon-energy",
    },
    "SYMPHONY": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/consumer-goods-white-goods/symphony/SCS04",
        "investing_link": "https://in.investing.com/equities/symphony-ltd",
    },
    "SYNGENE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/syngeneinternational/SI10",
        "investing_link": "https://in.investing.com/equities/syngene-international-ltd",
    },
    "TANLA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software-mediumsmall/tanlaplatforms/TS11",
        "investing_link": "https://in.investing.com/equities/tanla-solutions",
    },
    "TATACHEM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/tatachemicals/TC",
        "investing_link": "https://in.investing.com/equities/tata-chemicals",
    },
    "TATACOFFEE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/plantations-teacoffee/tatacoffee/TC14",
        "investing_link": "https://in.investing.com/equities/tata-coffee",
    },
    "TATACOMM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/telecommunications-service/tatacommunications/TC17",
        "investing_link": "https://in.investing.com/equities/tata-communications",
    },
    "TCS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/tataconsultancyservices/TCS",
        "investing_link": "https://in.investing.com/equities/tata-consultancy-services",
    },
    "TATACONSUM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/plantations-teacoffee/tataconsumerproducts/TT",
        "investing_link": "https://in.investing.com/equities/tata-global-beverages",
    },
    "TATAELXSI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/tataelxsi/TE",
        "investing_link": "https://in.investing.com/equities/tata-elxsi-limited",
    },
    "TATAINVEST": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investments/tatainvestmentcorporation/TIC",
        "investing_link": "https://in.investing.com/equities/tata-investment-corporation",
    },
    "TATAMTRDVR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries/tatamotors-dvr/TATAM57000",
        "investing_link": "https://in.investing.com/equities/tata-motors-dv-ltd",
    },
    "TATAMOTORS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-lcvshcvs/tatamotors/TM03",
        "investing_link": "https://in.investing.com/equities/tata-motors-ltd",
    },
    "TATAPOWER\r": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/thetatapowercompany/TPC",
        "investing_link": "https://in.investing.com/equities/tata-power-company",
    },
    "TATASTLLP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/steel-sponge-iron/tatasteellongproducts/TSI",
        "investing_link": "https://in.investing.com/equities/tata-sponge-iron",
    },
    "TATASTEEL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/ironsteel/tatasteel/TIS",
        "investing_link": "https://in.investing.com/equities/tata-steel",
    },
    "TTML": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/telecommunications-service/tatateleservicesmaharashtra/TTM01",
        "investing_link": "https://in.investing.com/equities/tata-teleservices-(maharashtra)",
    },
    "TCIEXP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/transportlogistics/tciexpress/TCI08",
        "investing_link": "https://in.investing.com/equities/tci-express-ltd",
    },
    "TCNSBRANDS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-general/tcnsclothingco/TCC",
        "investing_link": "https://in.investing.com/equities/tcns-clothing-co",
    },
    "TEAMLEASE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/teamleaseservices/TS13",
        "investing_link": "https://in.investing.com/equities/teamlease-services-ltd",
    },
    "TECHM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/techmahindra/TM4",
        "investing_link": "https://in.investing.com/equities/tech-mahindra",
    },
    "NIACL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/newindiaassurancecompany/NIA",
        "investing_link": "https://in.investing.com/equities/new-india-assurance-ltd",
    },
    "RAMCOCEM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/theramcocements/MC",
        "investing_link": "https://in.investing.com/equities/madras-cements",
    },
    "THERMAX": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/infrastructure-general/thermax/T",
        "investing_link": "https://in.investing.com/equities/thermax",
    },
    "THYROCARE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hospitalsmedical-services/thyrocaretechnologies/TT16",
        "investing_link": "https://in.investing.com/equities/thyrocare-technologies-ltd",
    },
    "TIMKEN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/bearings/timkenindia/TI23",
        "investing_link": "https://in.investing.com/equities/timken-india-ltd",
    },
    "TITAN": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/titancompany/TI01",
        "investing_link": "https://in.investing.com/equities/titan-industries",
    },
    "TORNTPHARM": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/torrentpharmaceuticals/TP06",
        "investing_link": "https://in.investing.com/equities/torrent-pharmaceuticals",
    },
    "TORNTPOWER": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/power-generationdistribution/torrentpower/TP14",
        "investing_link": "https://in.investing.com/equities/torrent-power",
    },
    "TRENT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/retail/trent/T04",
        "investing_link": "https://in.investing.com/equities/trent",
    },
    "TRIDENT": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-spinning-cotton-blended/trident/AI01",
        "investing_link": "https://in.investing.com/equities/trident",
    },
    "TRIVENI": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/sugar/triveniengineeringindustries/TE10",
        "investing_link": "https://in.investing.com/equities/triveni-engineering",
    },
    "TRITURBINE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/electric-equipment/triveniturbine/TT14",
        "investing_link": "https://in.investing.com/equities/triveni-turbine-ltd",
    },
    "TTKPRESTIG": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/domestic-appliances/ttkprestige/TTK02",
        "investing_link": "https://in.investing.com/equities/ttk-prestige-ltd",
    },
    "TIINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries/tubeinvestmentsindialtd/TIIND54076",
        "investing_link": "https://in.investing.com/equities/tube-invest-india",
    },
    "TV18BRDCST": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/mediaentertainment/tv18broadcast/IBN",
        "investing_link": "https://in.investing.com/equities/tv18-broadcast",
    },
    "TVSMOTOR": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-23-wheelers/tvsmotorcompany/TVS",
        "investing_link": "https://in.investing.com/equities/tvs-motor-company",
    },
    "UCOBANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/ucobank/UCO",
        "investing_link": "https://in.investing.com/equities/uco-bank",
    },
    "UFLEX": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/packaging/uflex/U01",
        "investing_link": "https://in.investing.com/equities/uflex",
    },
    "ULTRACEMCO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/cement-major/ultratechcement/UTC01",
        "investing_link": "https://in.investing.com/equities/ultratech-cement",
    },
    "UNIONBANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-public-sector/unionbankindia/UBI01",
        "investing_link": "https://in.investing.com/equities/union-bank-of-india",
    },
    "UBL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/breweriesdistilleries/unitedbreweries/UB02",
        "investing_link": "https://in.investing.com/equities/united-breweries",
    },
    "MCDOWELL-N": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/breweriesdistilleries/unitedspirits/US",
        "investing_link": "https://in.investing.com/equities/united-spirits",
    },
    "UPL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/upl/UP04",
        "investing_link": "https://in.investing.com/equities/united-phosphorus",
    },
    "UTIAMC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/finance-investment/utiassetmanagementcompany/UA04",
        "investing_link": "https://in.investing.com/equities/uti-asset-management",
    },
    "VGUARD": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/electric-equipment/v-guardindustries/VI02",
        "investing_link": "https://in.investing.com/equities/v-guard-industries-ltd",
    },
    "VMART": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/retail/v-martretail/VR03",
        "investing_link": "https://in.investing.com/equities/v-mart-retail-ltd",
    },
    "VIPIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/householdpersonal-products/vipindustries/VIP",
        "investing_link": "https://in.investing.com/equities/vip-industries",
    },
    "VAIBHAVGBL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/retail/vaibhavglobal/VG02",
        "investing_link": "https://in.investing.com/equities/vaibhav-glo",
    },
    "VAKRANGEE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software-mediumsmall/vakrangee/VS",
        "investing_link": "https://in.investing.com/equities/vakrangee-softwares-ltd",
    },
    "VTL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-spinning-cotton-blended/vardhmantextiles/VT10",
        "investing_link": "https://in.investing.com/equities/vardhman-textiles-ltd",
    },
    "VARROC": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/engineering-heavy/varrocengineering/VE08",
        "investing_link": "https://in.investing.com/equities/varroc-engineering-ltd",
    },
    "VBL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/food-processing/varunbeverages/VB05",
        "investing_link": "https://in.investing.com/equities/varun-beverages-ltd",
    },
    "VEDL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miningminerals/vedanta/SG",
        "investing_link": "https://in.investing.com/equities/sesa-goa",
    },
    "VENKEYS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/miscellaneous/venkys/V03",
        "investing_link": "https://in.investing.com/equities/venkys-(india)",
    },
    "VIJAYA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hospitalhealthcare-services/vijayadiagnosticcentre/VDC01",
        "investing_link": "https://in.investing.com/equities/vijaya-diagnostic-centre",
    },
    "VINATIORGA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/chemicals/vinatiorganics/VO01",
        "investing_link": "https://in.investing.com/equities/vinati-organics-ltd",
    },
    "IDEA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/telecommunications-service/vodafoneidealimited/IC8",
        "investing_link": "https://in.investing.com/equities/idea-cellular",
    },
    "VOLTAS": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/diversified/voltas/V",
        "investing_link": "https://in.investing.com/equities/voltas",
    },
    "WELCORP": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/steel-tubespipes/welspuncorp/WGS",
        "investing_link": "https://in.investing.com/equities/welspun-corp",
    },
    "WELSPUNIND": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/textiles-weaving/welspunindia/WI03",
        "investing_link": "https://in.investing.com/equities/welspun-ind",
    },
    "WESTLIFE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/hotel-resortrestaurants/westlifefoodworld/DIC",
        "investing_link": "https://in.investing.com/equities/westlife-development-ltd-bo",
    },
    "WHIRLPOOL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/consumer-goods-white-goods/whirlpoolindia/WI",
        "investing_link": "https://in.investing.com/equities/whirlpool-of-india",
    },
    "WIPRO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/wipro/W",
        "investing_link": "https://in.investing.com/equities/wipro-ltd",
    },
    "WOCKPHARMA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticals/wockhardt/W05",
        "investing_link": "https://in.investing.com/equities/wockhardt",
    },
    "YESBANK": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/banks-private-sector/yesbank/YB",
        "investing_link": "https://in.investing.com/equities/yes-bank",
    },
    "ZEEL": {
        "moneycontrol_link": "moneycontrol.com/india/stockpricequote/mediaentertainment/zeeentertainmententerprises/ZEE",
        "investing_link": "https://in.investing.com/equities/zee-entertainment-enterprises",
    },
    "ZENSARTECH": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/computers-software/zensartechnologies/ZT02",
        "investing_link": "https://in.investing.com/equities/zensar-technologies",
    },
    "ZFCVINDIA": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/auto-ancillaries-others/zfcommercialvehiclecontrolsystemsindia/WAB",
        "investing_link": "https://in.investing.com/equities/wabco-india-ltd",
    },
    "ZOMATO": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/online-services/zomato/Z",
        "investing_link": "https://in.investing.com/equities/zomato",
    },
    "ZYDUSLIFE": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/pharmaceuticalsdrugs/zyduslifesciences/CHC",
        "investing_link": "https://in.investing.com/equities/cadila-healthcare",
    },
    "ZYDUSWELL": {
        "moneycontrol_link": "https://www.moneycontrol.com/india/stockpricequote/vanaspatioils/zyduswellness/ZW01",
        "investing_link": "https://in.investing.com/equities/zydus-wellness",
    },
}
